summaryrefslogtreecommitdiffstats
path: root/kolourpaint/tools/kptoolautocrop.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:56:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:56:05 -0600
commit74c05bbf9d92e43a6cf3799355b5f3598884409e (patch)
tree9371e52e1564e08fd280f28e49981ffeb881b9d2 /kolourpaint/tools/kptoolautocrop.cpp
parent45f529de247fc4b3662f6b474abe03fe904306ec (diff)
downloadtdegraphics-74c05bbf9d92e43a6cf3799355b5f3598884409e.tar.gz
tdegraphics-74c05bbf9d92e43a6cf3799355b5f3598884409e.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kolourpaint/tools/kptoolautocrop.cpp')
-rw-r--r--kolourpaint/tools/kptoolautocrop.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kolourpaint/tools/kptoolautocrop.cpp b/kolourpaint/tools/kptoolautocrop.cpp
index 41aeb398..c294b1d0 100644
--- a/kolourpaint/tools/kptoolautocrop.cpp
+++ b/kolourpaint/tools/kptoolautocrop.cpp
@@ -70,7 +70,7 @@ kpToolAutoCropBorder::kpToolAutoCropBorder (const TQPixmap *pixmapPtr,
: m_pixmapPtr (pixmapPtr),
m_processedColorSimilarity (processedColorSimilarity)
{
- tqinvalidate ();
+ invalidate ();
}
@@ -280,7 +280,7 @@ bool kpToolAutoCropBorder::exists () const
}
// public
-void kpToolAutoCropBorder::tqinvalidate ()
+void kpToolAutoCropBorder::invalidate ()
{
m_rect = TQRect ();
m_referenceColor = kpColor::invalid;
@@ -374,7 +374,7 @@ bool kpToolAutoCrop (kpMainWindow *mainWindow)
// and regression testing.
//
// TODO: e.g. When the top fills entire rect but bot doesn't we could
// tqinvalidate top and continue autocrop.
int numRegions = 0;
if (!leftBorder.calculate (true/*x*/, +1/*going right*/) ||
leftBorder.fillsEntirePixmap () ||
@@ -439,7 +439,7 @@ bool kpToolAutoCrop (kpMainWindow *mainWindow)
#if DEBUG_KP_TOOL_AUTO_CROP
kdDebug () << "\tignoring left border" << endl;
#endif
- leftBorder.tqinvalidate ();
+ leftBorder.invalidate ();
}
}
@@ -454,7 +454,7 @@ bool kpToolAutoCrop (kpMainWindow *mainWindow)
#if DEBUG_KP_TOOL_AUTO_CROP
kdDebug () << "\tignoring top border" << endl;
#endif
- topBorder.tqinvalidate ();
+ topBorder.invalidate ();
}
}
@@ -374,7 +374,7 @@ bool kpToolAutoCrop (kpMainWindow *mainWindow)
//
// TODO: e.g. When the top fills entire rect but bot doesn't we could
- // tqinvalidate top and continue autocrop.
+ // invalidate top and continue autocrop.
int numRegions = 0;
if (!leftBorder.calculate (true/*x*/, +1/*going right*/) ||